@@ -1,12 +1,12 @@
-from typing import Optional
+"""Title module"""
 import numpy as np
 from PIL import Image, ImageDraw, ImageOps
 
 from .text import get_default_font, image_add_text, StrOrColor
 from ...logger import logger
 
-def image_add_title(image: np.ndarray, text: str, font: Optional[str]=None, font_color: str="white",
-                    background_color: StrOrColor="black", top_padding: int=None, size_px: int=None) -> np.ndarray:
+def image_add_title(image: np.ndarray, text: str, font: str = None, font_color: str = "white",
+                    background_color: StrOrColor = "black", top_padding: int = None, size_px: int = None) -> np.ndarray:
     """Calls image_add_text to add title on an updated image with padding on top for space and text centered"""
     assert len(image.shape) == 3, f"Wrong image shape: {image.shape}"
     height, _ = image.shape[0 : 2]
@@ -16,7 +16,7 @@ def image_add_title(image: np.ndarray, text: str, font: Optional[str]=None, font
     if top_padding is None:
         top_padding = int(height * 0.15)
         logger.debug2(f"Top padding not provided. Giving 15% of the image = {top_padding}")
-    
+
     if size_px is None:
         size_px = top_padding
 
