@@ -1,6 +1,8 @@
+"""Utils module"""
 from typing import Set
 from ...logger import logger
 
+# pylint: disable=import-outside-toplevel, unused-import
 def get_available_image_libs() -> Set[str]:
     """Returns a set with all the available image libraries used for reading/writing"""
 
@@ -8,25 +10,25 @@ def get_available_image_libs() -> Set[str]:
     try:
         import PIL
         res.add("PIL")
-    except:
+    except ModuleNotFoundError:
         pass
-    
+
     try:
         import lycon
         res.add("lycon")
-    except:
+    except ModuleNotFoundError:
         pass
 
     try:
         import cv2
         res.add("opencv")
-    except:
+    except ModuleNotFoundError:
         pass
 
     try:
         import skimage
         res.add("skimage")
-    except:
+    except ModuleNotFoundError:
         pass
 
     if len(res) == 0:
