@@ -1,4 +1,4 @@
+"""Init file"""
 from .mpl_video import MPLVideo
 from .video_reader import video_read
 from .video_writer import video_write
-from .utils import *
