@@ -1,2 +1,2 @@
-from .reader import video_read
-from .writer import video_write
\ No newline at end of file
+"""Init file"""
+from .writer import video_write
